Module: Google::Cloud::ManagedKafka::SchemaRegistry
- Defined in:
- lib/google/cloud/managed_kafka/schema_registry.rb,
lib/google/cloud/managed_kafka/schema_registry/version.rb
Constant Summary collapse
- VERSION =
"0.3.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.managed_kafka_schema_registry| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-managed_kafka-schema_registry library.
-
.managed_schema_registry(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ManagedSchemaRegistry.
-
.managed_schema_registry_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ManagedSchemaRegistry service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.managed_kafka_schema_registry| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-managed_kafka-schema_registry library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
196 197 198 199 200 |
# File 'lib/google/cloud/managed_kafka/schema_registry.rb', line 196 def self.configure yield ::Google::Cloud.configure.managed_kafka_schema_registry if block_given? ::Google::Cloud.configure.managed_kafka_schema_registry end |
.managed_schema_registry(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ManagedSchemaRegistry.
By default, this returns an instance of
Google::Cloud::ManagedKafka::SchemaRegistry::V1::ManagedSchemaRegistry::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ManagedSchemaRegistry service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ManagedSchemaRegistry service. You can determine whether the method will succeed by calling managed_schema_registry_available?.
About ManagedSchemaRegistry
SchemaRegistry is a service that allows users to manage schemas for their Kafka clusters. It provides APIs to register, list, and delete schemas, as well as to get the schema for a given schema id or a given version id under a subject, to update the global or subject-specific compatibility mode, and to check the compatibility of a schema against a subject or a version. The main resource hierarchy is as follows:
- SchemaRegistry
- SchemaRegistry/Context
- SchemaRegistry/Context/Schema
- SchemaRegistry/Context/Subject
- SchemaRegistry/Context/Subject/Version
- SchemaRegistry/Config
- SchemaRegistry/Mode
SchemaRegistry is the root resource to represent a schema registry instance. A customer can have multiple schema registry instances in a project.
Context is a context resource that represents a group of schemas, subjects and versions. A schema registry instance can have multiple contexts and always has a 'default' context. Contexts are independent of each other. Context is optional and if not specified, it falls back to the 'default' context.
Schema is a schema resource that represents a unique schema in a context of a schema registry instance. Each schema has a unique schema id, and can be referenced by a version of a subject.
Subject refers to the name under which the schema is registered. A typical subject is the Kafka topic name. A schema registry instance can have multiple subjects.
Version represents a version of a subject. A subject can have multiple versions. Creation of new version of a subject is guarded by the compatibility mode configured globally or for the subject specifically.
Config represents a config at global level cross all registry instances or at subject level. Currently, only compatibility is supported in config.
Mode represents the mode of a schema registry or a specific subject. Three modes are supported:
- READONLY: The schema registry is in read-only mode, no write operations allowed..
- READWRITE: The schema registry is in read-write mode, which allows limited write operations on the schema.
- IMPORT: The schema registry is in import mode, which allows more editing operations on the schema for data importing purposes.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/cloud/managed_kafka/schema_registry.rb', line 124 def self.managed_schema_registry version: :v1, transport: :grpc, &block require "google/cloud/managed_kafka/schema_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ManagedKafka::SchemaRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::ManagedKafka::SchemaRegistry.const_get(package_name).const_get(:ManagedSchemaRegistry) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.managed_schema_registry_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ManagedSchemaRegistry service is supported by the current client. If true, you can retrieve a client object by calling managed_schema_registry. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ManagedSchemaRegistry service, or if the versioned client gem needs an update to support the ManagedSchemaRegistry service.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/google/cloud/managed_kafka/schema_registry.rb', line 148 def self.managed_schema_registry_available? version: :v1, transport: :grpc require "google/cloud/managed_kafka/schema_registry/#{version.to_s.downcase}" package_name = Google::Cloud::ManagedKafka::SchemaRegistry .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::ManagedKafka::SchemaRegistry.const_get package_name return false unless service_module.const_defined? :ManagedSchemaRegistry service_module = service_module.const_get :ManagedSchemaRegistry if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |